This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-text.git


The following commit(s) were added to refs/heads/master by this push:
     new 9eaf80c  Use the scale in the var name.
9eaf80c is described below

commit 9eaf80cd4ec6264bb589ff6a8ed9cced8564b4c0
Author: Gary Gregory <gardgreg...@gmail.com>
AuthorDate: Tue Feb 2 17:52:50 2021 -0500

    Use the scale in the var name.
---
 src/main/java/org/apache/commons/text/lookup/DateStringLookup.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/main/java/org/apache/commons/text/lookup/DateStringLookup.java 
b/src/main/java/org/apache/commons/text/lookup/DateStringLookup.java
index b3bcb9c..a31bbc3 100644
--- a/src/main/java/org/apache/commons/text/lookup/DateStringLookup.java
+++ b/src/main/java/org/apache/commons/text/lookup/DateStringLookup.java
@@ -61,11 +61,11 @@ final class DateStringLookup extends AbstractStringLookup {
     /**
      * Formats the given {@code date} long with the given {@code format}.
      *
      * @param date the date to format
      * @param format the format string for {@link SimpleDateFormat}.
      * @return The formatted date
      */
-    private String formatDate(final long date, final String format) {
+    private String formatDate(final long dateMillis, final String format) {
         FastDateFormat dateFormat = null;
         if (format != null) {
             try {
@@ -77,7 +77,7 @@ final class DateStringLookup extends AbstractStringLookup {
         if (dateFormat == null) {
             dateFormat = FastDateFormat.getInstance();
         }
-        return dateFormat.format(new Date(date));
+        return dateFormat.format(new Date(dateMillis));
     }
 
     /**
@@ -61,11 +61,11 @@ final class DateStringLookup extends AbstractStringLookup {
      * Formats the given {@code date} long with the given {@code format}.
      *
-     * @param date the date to format
+     * @param dateMillis the date to format
      * @param format the format string for {@link SimpleDateFormat}.
      * @return The formatted date

Reply via email to